What’s new in version 1.1.1
===========================
Version available since March 28th 2022


New Features
------------
- A new function in 'analyse' package, computeJacobian, to display gradients of outputs according to given inputs.


Contributors
------------
Lucas Agobert
